"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.editableRowWrapper = void 0;
const tslib_1 = require("tslib");
const React = tslib_1.__importStar(require("react"));
const react_dom_1 = require("react-dom");
const react_styles_1 = require("@patternfly/react-styles");
const utils_1 = require("../../utils/utils");
const inline_edit_css_1 = require("./css/inline-edit-css");
const ConfirmButtons_1 = require("../ConfirmButtons");
require("@patternfly/react-styles/css/components/Table/inline-edit.css");
// TableEditConfirmation constants like TABLE_TOP cannot be referenced but must be hardcoded due to this issue:
// https://github.com/reactjs/react-docgen/issues/317#issue-393678795
const tableConfirmationMapper = {
    TABLE_TOP: {
        hasConfirmationButtons: ({ isTableEditing, isFirstVisible }) => isTableEditing && isFirstVisible,
        isTableConfirmation: () => true,
        areButtonsOnTop: () => true,
        hasBoldBorder: () => true,
        getEditStyles: ({ isTableEditing, isFirstVisible }) => (0, react_styles_1.css)(inline_edit_css_1.inlineEditStyles.tableEditableRow, isTableEditing && isFirstVisible && inline_edit_css_1.inlineEditStyles.modifiers.tableEditingFirstRow)
    },
    TABLE_BOTTOM: {
        hasConfirmationButtons: ({ isTableEditing, isLastVisible }) => isTableEditing && isLastVisible,
        isTableConfirmation: () => true,
        areButtonsOnTop: () => false,
        hasBoldBorder: () => true,
        getEditStyles: ({ isTableEditing, isLastVisible }) => (0, react_styles_1.css)(inline_edit_css_1.inlineEditStyles.tableEditableRow, isTableEditing && isLastVisible && inline_edit_css_1.inlineEditStyles.modifiers.tableEditingLastRow)
    },
    ROW: {
        hasConfirmationButtons: ({ isEditing, isParentEditing, isLastVisibleParent, isChildEditing, isLastVisible }) => isEditing &&
            !(isChildEditing && isParentEditing) && // buttons can't appear in the middle
            !(isParentEditing && isLastVisible) && // parent will show the buttons on top
            !(isChildEditing && !isLastVisibleParent),
        isTableConfirmation: () => false,
        areButtonsOnTop: ({ isLastVisible, isLastVisibleParent }) => isLastVisible || isLastVisibleParent,
        hasBoldBorder: () => false,
        getEditStyles: ({ isEditing }) => (0, react_styles_1.css)(inline_edit_css_1.inlineEditStyles.tableEditableRow, isEditing && inline_edit_css_1.inlineEditStyles.modifiers.editing)
    },
    NO_CONFIRM_ROW: {
        hasConfirmationButtons: () => false,
        isTableConfirmation: () => false,
        areButtonsOnTop: () => false,
        hasBoldBorder: () => false,
        getEditStyles: ({ isEditing }) => (0, react_styles_1.css)(inline_edit_css_1.inlineEditStyles.tableEditableRow, isEditing && inline_edit_css_1.inlineEditStyles.modifiers.editing)
    },
    NONE: {
        hasConfirmationButtons: () => false,
        isTableConfirmation: () => false,
        areButtonsOnTop: () => false,
        hasBoldBorder: () => false,
        getEditStyles: () => (0, react_styles_1.css)(inline_edit_css_1.inlineEditStyles.tableEditableRow)
    }
};
const getTableConfirmation = ({ editConfig }) => (editConfig && tableConfirmationMapper[editConfig.editConfirmationType]) ||
    tableConfirmationMapper.NONE;
const editableRowWrapper = (RowWrapperComponent) => { var _a; return _a = class EditableRowWrapper extends React.Component {
        constructor() {
            super(...arguments);
            this.state = Object.assign({ hasConfirmationButtons: false, window: undefined, rowDimensions: undefined }, EditableRowWrapper.getDerivedStateFromProps(this.props));
            this.element = React.createRef();
            this.setStateWith2dEquals = (newState) => {
                this.setState(oldState => Object.keys(newState).find(key => !(0, utils_1.shallowLeftSideEquals)(newState[key], oldState[key]))
                    ? newState
                    : null);
            };
            this.updateRowDimensions = () => {
                if (this.element.current) {
                    this.setStateWith2dEquals({
                        rowDimensions: (0, utils_1.getBoundingClientRect)(this.element.current)
                    });
                }
            };
            this.handleScroll = () => {
                this.updateRowDimensions();
            };
            this.handleResize = () => {
                this.fetchClientDimensions();
                this.updateRowDimensions();
            };
        }
        componentDidMount() {
            this.tableElem = this.element.current.closest('table');
            if (typeof this.props.trRef === 'function') {
                this.props.trRef(this.element.current);
            }
            this.updateRowDimensions();
            if (this.state.hasConfirmationButtons) {
                this.fetchClientDimensions();
            }
        }
        fetchClientDimensions() {
            this.setStateWith2dEquals({
                window: (0, utils_1.getClientWindowDimensions)()
            });
        }
        getConfirmationButtons() {
            const _a = this.props, { row, rowProps } = _a, props = tslib_1.__rest(_a, ["row", "rowProps"]);
            const { isLastVisible, isParentEditing, isLastVisibleParent, editConfig } = row;
            if (!editConfig) {
                return null;
            }
            const { onEditConfirmed, onEditCanceled } = editConfig;
            const tableConfirmation = getTableConfirmation(row);
            let confirmButtons;
            if (this.element.current && this.state.rowDimensions) {
                const options = tableConfirmation.isTableConfirmation() ? {} : rowProps;
                const actionObject = tableConfirmation.isTableConfirmation() ? null : row;
                confirmButtons = (0, react_dom_1.createPortal)(React.createElement(ConfirmButtons_1.ConfirmButtons, Object.assign({}, props, { onConfirm: event => onEditConfirmed(event, actionObject, options), onCancel: event => onEditCanceled(event, actionObject, options), buttonsOnTop: tableConfirmation.areButtonsOnTop({ isLastVisible, isParentEditing, isLastVisibleParent }), boldBorder: tableConfirmation.hasBoldBorder(), environment: {
                        window: this.state.window,
                        row: (0, utils_1.getBoundingClientRect)(this.element.current)
                    } })), this.tableElem ? this.tableElem.parentNode : document.body);
            }
            return confirmButtons;
        }
        render() {
            const { className, onScroll, onResize, row: { isFirstVisible, isLastVisible, isEditing, isTableEditing, editConfig } } = this.props;
            const { hasConfirmationButtons } = this.state;
            const trClassName = getTableConfirmation({ editConfig }).getEditStyles({
                isEditing,
                isTableEditing,
                isFirstVisible,
                isLastVisible
            });
            return (React.createElement(React.Fragment, null,
                React.createElement(RowWrapperComponent, Object.assign({}, this.props, { trRef: this.element, className: (0, react_styles_1.css)(trClassName, className), onScroll: event => {
                        if (hasConfirmationButtons) {
                            this.handleScroll();
                        }
                        onScroll(event);
                    }, onResize: event => {
                        if (hasConfirmationButtons) {
                            this.handleResize();
                        }
                        onResize(event);
                    } })),
                hasConfirmationButtons && this.getConfirmationButtons()));
        }
    },
    _a.defaultProps = {
        onScroll: () => { },
        onResize: () => { }
    },
    _a.getDerivedStateFromProps = (props) => ({
        hasConfirmationButtons: getTableConfirmation(props.row).hasConfirmationButtons(props.row)
    }),
    _a; };
exports.editableRowWrapper = editableRowWrapper;
//# sourceMappingURL=editableRowWrapper.js.map